import i18n from '@/lang'

const $t = function() {
  return i18n.t.apply(i18n, arguments)
}
// console.log(i18n.t("valid.required"))
const validateForm = {
  // 手机验证 （element Form规则)
  mobile: (rule, value, callback) => {
    if (!value) {
      callback(new Error($t('valid.required', [$t('input.telephone')])))
    }
    var reg = /^[1][0-9][0-9]{9}$/
    if (value.length < 11 || !reg.test(value)) {
      callback(
        new Error($t('valid.formatError', [$t('input.telephone')]))
      )
    }
    callback()
  },
  getJiaMi: function(str) {
    if (!str || str.length <= 6) return
    var str1 = str.substring(0, 3)
    var str2 = str.substring(str.length - 3, str.length)
    var strbu = ''
    var n = str.length - 6
    for (var c = 0; c < n; c++) {
      strbu += '*'
    }
    return str1 + strbu + str2
  },
  // 手机验证 （element Form规则)
  email: (rule, value, callback) => {
    if (!value) {
      callback(new Error($t('valid.required', [$t('input.email')])))
    }
    var reg = /^\w+((.\w+)|(-\w+))@[A-Za-z0-9]+((.|-)[A-Za-z0-9]+).[A-Za-z0-9]+$/

    if (!reg.test(value)) {
      callback(new Error($t('valid.formatError', [$t('input.email')])))
    }
    callback()
  },

  // 校验重名 (仕杰风格) (status==-10000表示存在)
  isExist: (api, paramsKey, mes, requireMes) => { // @api：接口  @paramsKey：参数字段 @mes:存在提示信息  @requireMes:未输入提示信息
    return (rule, value, callback) => {
      if (!value) {
        callback(new Error(`请输入${requireMes}`))
        return
      }
      var params = {
        [paramsKey]: value
      }
      api(params).then(res => {
        callback()
      }).catch(err => {
        if (err.status == -10000) {
          callback(new Error(mes))
        } else {
          callback()
        }
      })
    }
  },
  // 校验重名  (桃红风格)(message=available代表可用，message=inavailable代表不可用
  isExist2: (api, paramsKey, mes, requireMes) => { // @api：接口  @paramsKey：参数字段 @mes:存在提示信息  @requireMes:未输入提示信息
    return (rule, value, callback) => {
      if (!value) {
        callback(new Error(`请输入${requireMes}`))
        return
      }
      var params = {
        [paramsKey]: value
      }
      api(params).then(res => {
        if (res.message == 'available') {
          callback()
        } else if (res.message == 'inavailable') {
          callback(new Error(mes))
        }
      }).catch(err => {
        callback()
      })
    }
  },
  // 校验重名  (桃红风格)(message=available代表可用，message=inavailable代表不可用
  isExist3: (api, paramsKey, mes, requireMes, saasId) => { // @api：接口  @paramsKey：参数字段 @mes:存在提示信息  @requireMes:未输入提示信息
    return (rule, value, callback) => {
      if (!value) {
        callback(new Error(`请输入${requireMes}`))
        return
      }
      var params = {
        [paramsKey]: value,
        saasId: saasId
      }
      api(params).then(res => {
        if (res.message == 'available') {
          callback()
        } else if (res.message == 'inavailable') {
          callback(new Error(mes))
        }
      }).catch(err => {
        callback()
      })
    }
  },
  // 校验重名  (逸祥风格)(obj=false代表可用，obj=true代表不可用
  isExist4: (api, paramsKey, mes, requireMes) => { // @api：接口  @paramsKey：参数字段 @mes:存在提示信息  @requireMes:未输入提示信息
    return (rule, value, callback) => {
      if (!value) {
        callback(new Error(`请输入${requireMes}`))
        return
      }
      var params = {
        [paramsKey]: value
      }
      api(params).then(res => {
        if (!res.obj) {
          callback()
        } else if (res.obj) {
          callback(new Error(mes))
        }
      }).catch(err => {
        callback()
      })
    }
  },
  idCard: (rule, value, callback) => {
    const reg = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/
    if (!value) {
      callback(new Error($t('valid.required', [$t('input.idCard')])))
    }
    if (!reg.test(value)) {
      callback(new Error($t('valid.formatError', [$t('input.idCard')])))
    }
    callback()
  },
  chinese: (rule, value, callback) => {
    const reg = /^[\u0391-\uFFE5]+$/
    if (!reg.test(value)) {
      callback(new Error($t('valid.formatError')))
    }
    callback(rule, value, callback)
  },
  numberAndLetter: () => {
    const reg = /^[0-9a-zA-Z]*$/
    if (!reg.test(value)) {
      callback(new Error($t('valid.formatError')))
    }
    callback()
  }
}

export default validateForm
